# mipscripts

mipscripts is a python package containing various tools for use with MIPTools
pipelines.

## Installation

You may install using pip:

```shell
pip install mipscripts
```

## Usage

mipscripts is setup as one uniform program containing multiple subcommands,
each designed for a different purpose. To use, simply type the name of the
package, followed by the subcommand:

```shell
python3 -m mipscripts subcommand [options]
```

## Developer Notes

When developing mipscripts, we recommend the use of a virtual environment:

```shell
python3 -m venv env
source env/bin/activate
```

The packages used during development are saved in the `requirements.txt` file.
To install, use pip:

```shell
pip install -r requirements.txt
````

If you update packages or add any new ones into the virtual environment, please
make sure to freeze the package versions before committing:

```shell
pip freeze > requirements.txt
```

After adding any new code, we encourage writing unit tests to test
functionality. mipscripts is tested via the [pytest
framework](https://docs.pytest.org/en/7.1.x/). To test the code, run:

```shell
python3 -m pytest
```
